@@ -14,7 +14,6 @@
 
 
 import contextlib
-import importlib.util
 import io
 import os
 import platform
@@ -27,7 +26,6 @@ from ..integrations.deepspeed import is_deepspeed_available
 from ..utils import (
     is_accelerate_available,
     is_flax_available,
-    is_safetensors_available,
     is_tf_available,
     is_torch_available,
     is_torch_hpu_available,
@@ -61,18 +59,13 @@ class EnvironmentCommand(BaseTransformersCLICommand):
         self._accelerate_config_file = accelerate_config_file
 
     def run(self):
-        safetensors_version = "not installed"
-        if is_safetensors_available():
-            import safetensors
+        import safetensors
 
-            safetensors_version = safetensors.__version__
-        elif importlib.util.find_spec("safetensors") is not None:
-            import safetensors
-
-            safetensors_version = f"{safetensors.__version__} but is ignored because of PyTorch version too old."
+        safetensors_version = safetensors.__version__
 
         accelerate_version = "not installed"
         accelerate_config = accelerate_config_str = "not found"
+
         if is_accelerate_available():
             import accelerate
             from accelerate.commands.config import default_config_file, load_config_from_file
