@@ -1,7 +1,13 @@
 from abc import ABC, abstractmethod
 from typing import Optional
 
+from ..utils import logging
 
+
+logger = logging.get_logger(__name__)
+
+
+# TODO joao, manuel: remove in v4.58.0
 class Constraint(ABC):
     r"""Abstract base class for all constraints that can be applied during generation.
     It must define how the constraint can be satisfied.
@@ -18,6 +24,9 @@ class Constraint(ABC):
     """
 
     def __init__(self):
+        logger.warning_once(
+            "Importing `Constraint` classes is deprecated and will be removed in v4.58.0. Constrained beam search has been moved to the Hub: https://hf.co/transformers-community/constrained-beam-search. Please import using `from transformers.generation import Constraint` instead."
+        )
         # test for the above condition
         self.test()
 
