@@ -794,8 +794,7 @@ def parse_log_history(log_history):
     if idx > 0:
         eval_results = {}
         for key, value in log_history[idx].items():
-            if key.startswith("eval_"):
-                key = key[5:]
+            key = key.removeprefix("eval_")
             if key not in ["runtime", "samples_per_second", "steps_per_second", "epoch", "step"]:
                 camel_cased_key = " ".join([part.capitalize() for part in key.split("_")])
                 eval_results[camel_cased_key] = value
