@@ -131,7 +131,7 @@ class ImageToImagePipeline(Pipeline):
         image = load_image(image, timeout=timeout)
         inputs = self.image_processor(images=[image], return_tensors="pt")
         if self.framework == "pt":
-            inputs = inputs.to(self.torch_dtype)
+            inputs = inputs.to(self.dtype)
         return inputs
 
     def postprocess(self, model_outputs):
