@@ -587,11 +587,11 @@ class PreTrainedTokenizer(PreTrainedTokenizerBase):
         self._update_total_vocab_size()
         return added_tokens
 
-    def _update_trie(self, unique_no_split_tokens: Optional[str] = []):
+    def _update_trie(self, unique_no_split_tokens: Optional[list[str]] = None):
         for token in self._added_tokens_decoder.values():
             if token.content not in self.tokens_trie._tokens:
                 self.tokens_trie.add(token.content)
-        for token in unique_no_split_tokens:
+        for token in unique_no_split_tokens or []:
             if token not in self.tokens_trie._tokens:
                 self.tokens_trie.add(token)
 
