@@ -13,6 +13,9 @@
 # limitations under the License.
 
 import copy
+import os
+import os.path
+import shutil
 import sys
 import tempfile
 import unittest
@@ -23,7 +26,7 @@ import pytest
 from huggingface_hub import Repository
 
 import transformers
-from transformers import BertConfig, GPT2Model, is_safetensors_available, is_torch_available
+from transformers import BertConfig, GPT2Model, is_torch_available
 from transformers.models.auto.configuration_auto import CONFIG_MAPPING
 from transformers.testing_utils import (
     DUMMY_UNKNOWN_IDENTIFIER,
@@ -39,6 +42,7 @@ from ..bert.test_modeling_bert import BertModelTester
 sys.path.append(str(Path(__file__).parent.parent.parent.parent / "utils"))
 
 from test_module.custom_configuration import CustomConfig  # noqa E402
+from utils.fetch_hub_objects_for_ci import url_to_local_path
 
 
 if is_torch_available():
@@ -108,7 +112,7 @@ class AutoModelTest(unittest.TestCase):
         self.assertEqual(len(loading_info["missing_keys"]), 0)
         # When using PyTorch checkpoint, the expected value is `8`. With `safetensors` checkpoint (if it is
         # installed), the expected value becomes `7`.
-        EXPECTED_NUM_OF_UNEXPECTED_KEYS = 7 if is_safetensors_available() else 8
+        EXPECTED_NUM_OF_UNEXPECTED_KEYS = 7
         self.assertEqual(len(loading_info["unexpected_keys"]), EXPECTED_NUM_OF_UNEXPECTED_KEYS)
         self.assertEqual(len(loading_info["mismatched_keys"]), 0)
         self.assertEqual(len(loading_info["error_msgs"]), 0)
@@ -556,7 +560,18 @@ class AutoModelTest(unittest.TestCase):
 
     def test_dynamic_saving_from_local_repo(self):
         with tempfile.TemporaryDirectory() as tmp_dir, tempfile.TemporaryDirectory() as tmp_dir_out:
-            _ = Repository(local_dir=tmp_dir, clone_from="hf-internal-testing/tiny-random-custom-architecture")
+            # `Repository` is deprecated and will be removed in `huggingface_hub v1.0`.
+            # TODO: Remove this test when this comes.
+            # Here is a ugly approach to avoid `too many requests`
+            repo_id = url_to_local_path("hf-internal-testing/tiny-random-custom-architecture")
+            if os.path.isdir(repo_id):
+                shutil.copytree(repo_id, tmp_dir, dirs_exist_ok=True)
+            else:
+                _ = Repository(
+                    local_dir=tmp_dir,
+                    clone_from=url_to_local_path("hf-internal-testing/tiny-random-custom-architecture"),
+                )
+
             model = AutoModelForCausalLM.from_pretrained(tmp_dir, trust_remote_code=True)
             model.save_pretrained(tmp_dir_out)
             _ = AutoModelForCausalLM.from_pretrained(tmp_dir_out, trust_remote_code=True)
@@ -579,3 +594,15 @@ class AutoModelTest(unittest.TestCase):
         # More precisely, it directly inherits from GenerationMixin. This check would fail prior to v4.45 (inheritance
         # patching was added in v4.45)
         self.assertTrue("GenerationMixin" in str(model.__class__.__bases__))
+
+    def test_model_with_dotted_name_and_relative_imports(self):
+        """
+        Test for issue #40496: AutoModel.from_pretrained() doesn't work for models with '.' in their name
+        when there's a relative import.
+
+        Without the fix, this raises: ModuleNotFoundError: No module named 'transformers_modules.test-model_v1'
+        """
+        model_id = "hf-internal-testing/remote_code_model_with_dots"
+
+        model = AutoModel.from_pretrained(model_id, trust_remote_code=True)
+        self.assertIsNotNone(model)
