@@ -16,16 +16,12 @@
 import gc
 import unittest
 
-import pytest
-
-from transformers import AutoTokenizer, Dots1Config, is_torch_available
+from transformers import AutoTokenizer, is_torch_available
 from transformers.testing_utils import (
     backend_empty_cache,
     cleanup,
-    require_flash_attn,
     require_torch,
     require_torch_accelerator,
-    require_torch_gpu,
     slow,
     torch_device,
 )
@@ -43,10 +39,8 @@ if is_torch_available():
 
 
 class Dots1ModelTester(CausalLMModelTester):
-    config_class = Dots1Config
     if is_torch_available():
         base_model_class = Dots1Model
-        causal_lm_class = Dots1ForCausalLM
 
     def __init__(
         self,
@@ -87,13 +81,6 @@ class Dots1ModelTest(CausalLMModelTest, unittest.TestCase):
     test_pruning = False
     model_tester_class = Dots1ModelTester
 
-    @require_flash_attn
-    @require_torch_gpu
-    @pytest.mark.flash_attn_test
-    @slow
-    def test_flash_attn_2_inference_equivalence_right_padding(self):
-        self.skipTest(reason="dots.llm1 flash attention does not support right padding")
-
 
 @require_torch_accelerator
 class Dots1IntegrationTest(unittest.TestCase):
