@@ -13,7 +13,7 @@
 # limitations under the License.
 import inspect
 import unittest
-from functools import reduce
+from functools import cached_property, reduce
 
 from datasets import load_dataset
 
@@ -23,11 +23,10 @@ from transformers.testing_utils import (
     require_vision,
     set_config_for_less_flaky_test,
     set_model_for_less_flaky_test,
-    set_model_tester_for_less_flaky_test,
     slow,
     torch_device,
 )
-from transformers.utils import cached_property, is_torch_available, is_vision_available
+from transformers.utils import is_torch_available, is_vision_available
 
 from ...test_configuration_common import ConfigTester
 from ...test_modeling_common import ModelTesterMixin, floats_tensor
@@ -47,18 +46,18 @@ class EfficientLoFTRModelTester:
         self,
         parent,
         batch_size=2,
-        image_width=80,
-        image_height=60,
-        stage_num_blocks: list[int] = [1, 1, 1],
-        out_features: list[int] = [32, 32, 128],
-        stage_stride: list[int] = [2, 1, 2],
+        image_width=6,  # need to be a multiple of `stage_stride[0] * stage_stride[1]`
+        image_height=4,  # need to be a multiple of `stage_stride[0] * stage_stride[1]`
+        stage_num_blocks: list[int] = [1, 1],
+        out_features: list[int] = [16, 16],  # need to be >= 2 to make `config.fine_fusion_dims > 0`
+        stage_stride: list[int] = [2, 1],
         q_aggregation_kernel_size: int = 1,
         kv_aggregation_kernel_size: int = 1,
         q_aggregation_stride: int = 1,
         kv_aggregation_stride: int = 1,
         num_attention_layers: int = 2,
         num_attention_heads: int = 8,
-        hidden_size: int = 128,
+        hidden_size: int = 16,
         coarse_matching_threshold: float = 0.0,
         fine_kernel_size: int = 2,
         coarse_matching_border_removal: int = 0,
@@ -211,7 +210,7 @@ class EfficientLoFTRModelTest(ModelTesterMixin, unittest.TestCase):
 
             hidden_states = outputs.hidden_states
 
-            expected_num_hidden_states = len(self.model_tester.stage_num_blocks)
+            expected_num_hidden_states = len(self.model_tester.stage_num_blocks) + 1
             self.assertEqual(len(hidden_states), expected_num_hidden_states)
 
             self.assertListEqual(
@@ -360,8 +359,6 @@ class EfficientLoFTRModelTest(ModelTesterMixin, unittest.TestCase):
                         msg += str(e)
                         raise AssertionError(msg)
 
-        set_model_tester_for_less_flaky_test(self)
-
         config, batched_input = self.model_tester.prepare_config_and_inputs_for_common()
         set_config_for_less_flaky_test(config)
 
