@@ -33,30 +33,18 @@ if is_torch_available():
 
     from transformers import (
         AutoTokenizer,
-        Ernie4_5Config,
         Ernie4_5ForCausalLM,
         Ernie4_5Model,
     )
-    from transformers.models.ernie4_5.modeling_ernie4_5 import Ernie4_5RotaryEmbedding
 
 
 class Ernie4_5ModelTester(CausalLMModelTester):
     if is_torch_available():
-        config_class = Ernie4_5Config
         base_model_class = Ernie4_5Model
-        causal_lm_class = Ernie4_5ForCausalLM
 
 
 @require_torch
 class Ernie4_5ModelTest(CausalLMModelTest, unittest.TestCase):
-    all_model_classes = (
-        (
-            Ernie4_5Model,
-            Ernie4_5ForCausalLM,
-        )
-        if is_torch_available()
-        else ()
-    )
     pipeline_model_mapping = (
         {
             "feature-extraction": Ernie4_5Model,
@@ -65,11 +53,8 @@ class Ernie4_5ModelTest(CausalLMModelTest, unittest.TestCase):
         if is_torch_available()
         else {}
     )
-    test_headmasking = False
-    test_pruning = False
     fx_compatible = False  # Broken by attention refactor cc @Cyrilvallez
     model_tester_class = Ernie4_5ModelTester
-    rotary_embedding_layer = Ernie4_5RotaryEmbedding  # Enables RoPE tests if set
 
     # Need to use `0.8` instead of `0.9` for `test_cpu_offload`
     # This is because we are hitting edge cases with the causal_mask buffer
