@@ -186,21 +186,21 @@ class FlavaProcessorTest(ProcessorTesterMixin, unittest.TestCase):
 
         inputs = processor(text=input_str, images=image_input)
 
-        self.assertListEqual(list(inputs.keys()), ["input_ids", "token_type_ids", "attention_mask", "pixel_values"])
+        self.assertSetEqual(set(inputs.keys()), {"input_ids", "token_type_ids", "attention_mask", "pixel_values"})
 
         # add extra args
         inputs = processor(text=input_str, images=image_input, return_codebook_pixels=True, return_image_mask=True)
 
-        self.assertListEqual(
-            list(inputs.keys()),
-            [
+        self.assertSetEqual(
+            set(inputs.keys()),
+            {
                 "input_ids",
                 "token_type_ids",
                 "attention_mask",
                 "pixel_values",
                 "codebook_pixel_values",
                 "bool_masked_pos",
-            ],
+            },
         )
 
         # test if it raises when no input is passed
