@@ -14,6 +14,7 @@
 
 import tempfile
 import unittest
+from functools import cached_property
 
 import timeout_decorator  # noqa
 from parameterized import parameterized
@@ -27,7 +28,6 @@ from transformers.testing_utils import (
     slow,
     torch_device,
 )
-from transformers.utils import cached_property
 
 from ...generation.test_utils import GenerationTesterMixin
 from ...test_configuration_common import ConfigTester
