@@ -15,6 +15,7 @@
 
 import math
 import unittest
+from functools import cached_property
 
 from transformers import HieraConfig
 from transformers.testing_utils import (
@@ -24,7 +25,6 @@ from transformers.testing_utils import (
     torch_device,
 )
 from transformers.utils import (
-    cached_property,
     is_torch_available,
     is_vision_available,
 )
