@@ -29,14 +29,12 @@ from ...causal_lm_tester import CausalLMModelTest, CausalLMModelTester
 
 
 if is_torch_available():
-    from transformers import Lfm2Config, Lfm2ForCausalLM, Lfm2Model
+    from transformers import Lfm2ForCausalLM, Lfm2Model
 
 
 class Lfm2ModelTester(CausalLMModelTester):
     if is_torch_available():
-        config_class = Lfm2Config
         base_model_class = Lfm2Model
-        causal_lm_class = Lfm2ForCausalLM
 
     def __init__(
         self,
@@ -49,7 +47,6 @@ class Lfm2ModelTester(CausalLMModelTester):
 
 @require_torch
 class Lfm2ModelTest(CausalLMModelTest, unittest.TestCase):
-    all_model_classes = (Lfm2Model, Lfm2ForCausalLM) if is_torch_available() else ()
     pipeline_model_mapping = (
         {
             "feature-extraction": Lfm2Model,
@@ -58,8 +55,6 @@ class Lfm2ModelTest(CausalLMModelTest, unittest.TestCase):
         if is_torch_available()
         else {}
     )
-    test_headmasking = False
-    test_pruning = False
     fx_compatible = False
     model_tester_class = Lfm2ModelTester
     # used in `test_torch_compile_for_training`
