@@ -38,7 +38,6 @@ if is_torch_available():
     import torch
 
     from transformers import (
-        LlamaConfig,
         LlamaForCausalLM,
         LlamaForQuestionAnswering,
         LlamaForSequenceClassification,
@@ -46,31 +45,15 @@ if is_torch_available():
         LlamaModel,
         LlamaTokenizer,
     )
-    from transformers.models.llama.modeling_llama import LlamaRotaryEmbedding
 
 
 class LlamaModelTester(CausalLMModelTester):
     if is_torch_available():
-        config_class = LlamaConfig
         base_model_class = LlamaModel
-        causal_lm_class = LlamaForCausalLM
-        sequence_class = LlamaForSequenceClassification
-        token_class = LlamaForTokenClassification
 
 
 @require_torch
 class LlamaModelTest(CausalLMModelTest, unittest.TestCase):
-    all_model_classes = (
-        (
-            LlamaModel,
-            LlamaForCausalLM,
-            LlamaForSequenceClassification,
-            LlamaForQuestionAnswering,
-            LlamaForTokenClassification,
-        )
-        if is_torch_available()
-        else ()
-    )
     pipeline_model_mapping = (
         {
             "feature-extraction": LlamaModel,
@@ -83,11 +66,8 @@ class LlamaModelTest(CausalLMModelTest, unittest.TestCase):
         if is_torch_available()
         else {}
     )
-    test_headmasking = False
-    test_pruning = False
     fx_compatible = False  # Broken by attention refactor cc @Cyrilvallez
     model_tester_class = LlamaModelTester
-    rotary_embedding_layer = LlamaRotaryEmbedding  # Enables RoPE tests if set
 
     # Need to use `0.8` instead of `0.9` for `test_cpu_offload`
     # This is because we are hitting edge cases with the causal_mask buffer
