@@ -15,6 +15,7 @@
 
 import copy
 import unittest
+from functools import cached_property
 
 import numpy as np
 
@@ -31,7 +32,6 @@ from transformers.testing_utils import (
     slow,
     torch_device,
 )
-from transformers.utils import cached_property
 
 from ...test_configuration_common import ConfigTester
 from ...test_modeling_common import ModelTesterMixin
@@ -219,7 +219,7 @@ class MaskFormerModelTest(ModelTesterMixin, PipelineTesterMixin, unittest.TestCa
         inputs_dict = copy.deepcopy(inputs_dict)
 
         if return_labels:
-            if model_class in [MaskFormerForInstanceSegmentation]:
+            if model_class == MaskFormerForInstanceSegmentation:
                 inputs_dict["mask_labels"] = torch.zeros(
                     (
                         self.model_tester.batch_size,
