@@ -16,6 +16,7 @@ import json
 import shutil
 import tempfile
 import unittest
+from typing import Optional
 
 import numpy as np
 
@@ -23,7 +24,7 @@ from transformers import MllamaProcessor
 from transformers.testing_utils import require_torch, require_vision
 from transformers.utils import is_vision_available
 
-from ...test_processing_common import ProcessorTesterMixin
+from ...test_processing_common import ProcessorTesterMixin, url_to_local_path
 
 
 if is_vision_available():
@@ -51,11 +52,21 @@ class MllamaProcessorTest(ProcessorTesterMixin, unittest.TestCase):
 
     @classmethod
     def tearDownClass(cls):
+        cls.image1.close()
+        cls.image2.close()
         shutil.rmtree(cls.tmpdirname, ignore_errors=True)
 
     def prepare_processor_dict(self):
         return {"chat_template": "{% for message in messages %}{% if loop.index0 == 0 %}{{ bos_token }}{% endif %}{{ '<|start_header_id|>' + message['role'] + '<|end_header_id|>\n\n' }}{% if message['content'] is string %}{{ message['content'] }}{% else %}{% for content in message['content'] %}{% if content['type'] == 'image' %}{{ '<|image|>' }}{% elif content['type'] == 'text' %}{{ content['text'] }}{% endif %}{% endfor %}{% endif %}{{ '<|eot_id|>' }}{% endfor %}{% if add_generation_prompt %}{{ '<|start_header_id|>assistant<|end_header_id|>\n\n' }}{% endif %}"}  # fmt: skip
 
+    # Override as Mllama needs images to be an explicitly nested batch
+    def prepare_image_inputs(self, batch_size: Optional[int] = None):
+        """This function prepares a list of PIL images for testing"""
+        images = super().prepare_image_inputs(batch_size)
+        if isinstance(images, (list, tuple)):
+            images = [[image] for image in images]
+        return images
+
     def test_chat_template_is_saved(self):
         processor_loaded = self.processor_class.from_pretrained(self.tmpdirname)
         processor_dict_loaded = json.loads(processor_loaded.to_json_string())
@@ -163,9 +174,19 @@ class MllamaProcessorTest(ProcessorTesterMixin, unittest.TestCase):
                 "role": "user",
                 "content": [
                     {"type": "text", "text": "Describe this image in two sentences"},
-                    {"type": "image", "url": "https://www.ilankelman.org/stopsigns/australia.jpg"},
+                    {
+                        "type": "image",
+                        "url": url_to_local_path(
+                            "https://huggingface.co/datasets/huggingface/documentation-images/resolve/main/transformers/tasks/australia.jpg"
+                        ),
+                    },
                     {"type": "text", "text": " Test sentence   "},
-                    {"type": "image", "url": "https://www.ilankelman.org/stopsigns/australia.jpg"},
+                    {
+                        "type": "image",
+                        "url": url_to_local_path(
+                            "https://huggingface.co/datasets/huggingface/documentation-images/resolve/main/transformers/tasks/australia.jpg"
+                        ),
+                    },
                     {"type": "text", "text": "ok\n"},
                 ],
             }
@@ -253,12 +274,14 @@ class MllamaProcessorTest(ProcessorTesterMixin, unittest.TestCase):
             [self.image_token_id, self.bos_token_id, 2028, 374, 264, 1296, 11914, 13],
             [self.bos_token_id, 2028, 374, 264, 1296, 11914, 13, self.image_token_id, self.image_token_id, 2028, 374, 264, 1296, 11914, 13],
         ]
-        # fmt: onn
+        # fmt: on
         images = [[self.image1], [self.image1, self.image2]]
         inputs = processor(text=text, images=images, padding=True, size={"width": 256, "height": 256})
 
         self.assertEqual(inputs["pixel_values"].shape, (2, 2, 4, 3, 256, 256))
-        for input_ids_i, attention_mask_i, expected_ids_i in zip(inputs["input_ids"], inputs["attention_mask"], expected_ids):
+        for input_ids_i, attention_mask_i, expected_ids_i in zip(
+            inputs["input_ids"], inputs["attention_mask"], expected_ids
+        ):
             pad_ids = [id for id, m in zip(input_ids_i, attention_mask_i) if m == 0]
             input_ids = [id for id, m in zip(input_ids_i, attention_mask_i) if m == 1]
             self.assertEqual(input_ids, expected_ids_i)
@@ -270,24 +293,38 @@ class MllamaProcessorTest(ProcessorTesterMixin, unittest.TestCase):
         # Check that only first tile of first sample is attended to all text tokens
         first_sample_mask = cross_attention_mask[0].copy()
         first_image_first_tile_attention = first_sample_mask[:, :1, :1]  # text tokens, images, tiles
-        self.assertTrue(np.all(first_image_first_tile_attention == 1), f"Cross attention mask is not all ones: {first_image_first_tile_attention}")
+        self.assertTrue(
+            np.all(first_image_first_tile_attention == 1),
+            f"Cross attention mask is not all ones: {first_image_first_tile_attention}",
+        )
 
         # zero out first tile of first image
         first_image_first_tile_attention[:, :1, :1] = 0
-        self.assertTrue(np.all(first_image_first_tile_attention == 0), f"Cross attention mask is not all zeros: {first_image_first_tile_attention}")
+        self.assertTrue(
+            np.all(first_image_first_tile_attention == 0),
+            f"Cross attention mask is not all zeros: {first_image_first_tile_attention}",
+        )
 
         # second sample
         second_sample_mask = cross_attention_mask[1].copy()
         first_image_first_tile_attention = second_sample_mask[7:, :1, :1]  # text tokens, images, tiles
-        self.assertTrue(np.all(first_image_first_tile_attention == 1), f"Cross attention mask is not all ones: {first_image_first_tile_attention}")
+        self.assertTrue(
+            np.all(first_image_first_tile_attention == 1),
+            f"Cross attention mask is not all ones: {first_image_first_tile_attention}",
+        )
 
         second_image_two_tiles_attention = second_sample_mask[8:, 1:2, :2]  # text tokens, images, tiles
-        self.assertTrue(np.all(second_image_two_tiles_attention == 1), f"Cross attention mask is not all ones: {second_image_two_tiles_attention}")
+        self.assertTrue(
+            np.all(second_image_two_tiles_attention == 1),
+            f"Cross attention mask is not all ones: {second_image_two_tiles_attention}",
+        )
 
         # zero out both images masks
         second_sample_mask[7:, :1, :1] = 0
         second_sample_mask[8:, 1:2, :2] = 0
-        self.assertTrue(np.all(second_sample_mask == 0), f"Cross attention mask is not all zeros: {second_sample_mask}")
+        self.assertTrue(
+            np.all(second_sample_mask == 0), f"Cross attention mask is not all zeros: {second_sample_mask}"
+        )
 
     def test_process_interleaved_images_prompts_image_error(self):
         text = [
@@ -344,7 +381,6 @@ class MllamaProcessorTest(ProcessorTesterMixin, unittest.TestCase):
 
         input_str = self.prepare_text_inputs(batch_size=2, modalities="image")
         image_input = self.prepare_image_inputs(batch_size=2)
-        image_input = [[image_input[0]], [image_input[1]]]
         inputs = processor(
             text=input_str,
             images=image_input,
@@ -368,7 +404,6 @@ class MllamaProcessorTest(ProcessorTesterMixin, unittest.TestCase):
 
         input_str = self.prepare_text_inputs(batch_size=2, modalities="image")
         image_input = self.prepare_image_inputs(batch_size=2)
-        image_input = [[image_input[0]], [image_input[1]]]
         _ = processor(
             text=input_str,
             images=image_input,
@@ -386,3 +421,7 @@ class MllamaProcessorTest(ProcessorTesterMixin, unittest.TestCase):
                 padding=True,
                 max_length=3,
             )
+
+    @unittest.skip("Mllama can't process inputs with no image ttogether with multimodal inputs")
+    def test_processor_text_has_no_visual(self):
+        pass
