@@ -17,6 +17,7 @@ import copy
 import math
 import tempfile
 import unittest
+from functools import cached_property
 
 from transformers import is_torch_available
 from transformers.testing_utils import (
@@ -27,7 +28,6 @@ from transformers.testing_utils import (
     slow,
     torch_device,
 )
-from transformers.utils import cached_property
 
 from ...generation.test_utils import GenerationTesterMixin
 from ...test_configuration_common import ConfigTester
