@@ -293,10 +293,6 @@ class PerceptionLMForConditionalGenerationModelTest(ModelTesterMixin, Generation
     def test_can_init_all_missing_weights(self):
         pass
 
-    @unittest.skip(reason="Timm Eva (PE) weights cannot be fully constructed in _init_weights")
-    def test_initialization(self):
-        pass
-
     @unittest.skip(
         reason="PE/TIMM's attention implementation is self configured and won't raise ValueError on global attention implementation."
     )
@@ -313,10 +309,6 @@ class PerceptionLMForConditionalGenerationModelTest(ModelTesterMixin, Generation
     def test_can_be_initialized_on_meta(self):
         pass
 
-    @unittest.skip("ViT PE / TimmWrapperModel cannot be tested with meta device")
-    def test_can_load_with_meta_device_context_manager(self):
-        pass
-
     @unittest.skip("Specifying both inputs_embeds and pixel_values are not supported for PerceptionLM")
     def test_generate_from_inputs_embeds_0_greedy(self):
         pass
@@ -436,7 +428,6 @@ class PerceptionLMForConditionalGenerationIntegrationTest(unittest.TestCase):
             tokenize=True,
             return_dict=True,
             return_tensors="pt",
-            video_load_backend="decord",
             padding=True,
             padding_side="left",
         ).to(torch_device)
@@ -462,7 +453,6 @@ class PerceptionLMForConditionalGenerationIntegrationTest(unittest.TestCase):
             tokenize=True,
             return_dict=True,
             return_tensors="pt",
-            video_load_backend="decord",
             padding=True,
             padding_side="left",
         ).to(torch_device)
