@@ -42,7 +42,6 @@ from ...generation.test_utils import GenerationTesterMixin
 from ...test_configuration_common import ConfigTester
 from ...test_modeling_common import (
     ModelTesterMixin,
-    _config_zero_init,
     floats_tensor,
     ids_tensor,
 )
@@ -65,24 +64,26 @@ class Qwen2VLVisionText2TextModelTester:
         num_channels=3,
         ignore_index=-100,
         image_size=14,
-        bos_token_id=0,
-        eos_token_id=1,
-        pad_token_id=2,
+        text_config={
+            "bos_token_id": 0,
+            "eos_token_id": 1,
+            "pad_token_id": 2,
+            "hidden_act": "silu",
+            "hidden_size": 32,
+            "vocab_size": 99,
+            "intermediate_size": 37,
+            "max_position_embeddings": 512,
+            "max_window_layers": 3,
+            "num_attention_heads": 4,
+            "num_hidden_layers": 2,
+            "num_key_value_heads": 2,
+            "rope_theta": 10000,
+            "tie_word_embeddings": True,
+            "rope_scaling": {"type": "mrope", "mrope_section": [2, 1, 1]},
+        },
         vision_start_token_id=3,
         image_token_id=4,
         video_token_id=5,
-        hidden_act="silu",
-        hidden_size=32,
-        vocab_size=99,
-        intermediate_size=37,
-        max_position_embeddings=512,
-        max_window_layers=3,
-        model_type="qwen2_vl",
-        num_attention_heads=4,
-        num_hidden_layers=4,
-        num_key_value_heads=2,
-        rope_theta=10000,
-        tie_word_embeddings=True,
         is_training=True,
         vision_config={
             "depth": 2,
@@ -95,58 +96,35 @@ class Qwen2VLVisionText2TextModelTester:
             "spatial_merge_size": 1,
             "temporal_patch_size": 2,
         },
-        rope_scaling={"type": "mrope", "mrope_section": [2, 1, 1]},
     ):
         self.parent = parent
         self.ignore_index = ignore_index
-        self.bos_token_id = bos_token_id
-        self.eos_token_id = eos_token_id
-        self.pad_token_id = pad_token_id
+        self.bos_token_id = text_config["bos_token_id"]
+        self.eos_token_id = text_config["eos_token_id"]
+        self.pad_token_id = text_config["pad_token_id"]
+        self.num_hidden_layers = text_config["num_hidden_layers"]
+        self.num_attention_heads = text_config["num_attention_heads"]
+        self.hidden_size = text_config["hidden_size"]
         self.vision_start_token_id = vision_start_token_id
         self.image_token_id = image_token_id
         self.video_token_id = video_token_id
-        self.hidden_act = hidden_act
-        self.hidden_size = hidden_size
-        self.intermediate_size = intermediate_size
-        self.max_position_embeddings = max_position_embeddings
-        self.max_window_layers = max_window_layers
-        self.model_type = model_type
-        self.num_attention_heads = num_attention_heads
-        self.num_hidden_layers = num_hidden_layers
-        self.num_key_value_heads = num_key_value_heads
-        self.rope_theta = rope_theta
-        self.tie_word_embeddings = tie_word_embeddings
+        self.text_config = text_config
         self.vision_config = vision_config
-        self.rope_scaling = rope_scaling
         self.batch_size = batch_size
         self.num_channels = num_channels
         self.image_size = image_size
         self.is_training = is_training
-        self.vocab_size = vocab_size
+        self.vocab_size = text_config["vocab_size"]
         self.num_image_tokens = 32
         self.seq_length = seq_length + self.num_image_tokens
 
     def get_config(self):
         return Qwen2VLConfig(
-            hidden_size=self.hidden_size,
-            intermediate_size=self.intermediate_size,
-            num_hidden_layers=self.num_hidden_layers,
-            num_attention_heads=self.num_attention_heads,
-            num_key_value_heads=self.num_key_value_heads,
-            hidden_act=self.hidden_act,
-            max_position_embeddings=self.max_position_embeddings,
+            text_config=self.text_config,
             vision_config=self.vision_config,
-            model_type=self.model_type,
-            max_window_layers=self.max_window_layers,
-            rope_scaling=self.rope_scaling,
-            tie_word_embeddings=self.tie_word_embeddings,
-            bos_token_id=self.bos_token_id,
-            eos_token_id=self.eos_token_id,
-            pad_token_id=self.pad_token_id,
             vision_start_token_id=self.vision_start_token_id,
             image_token_id=self.image_token_id,
             video_token_id=self.video_token_id,
-            vocab_size=self.vocab_size,
         )
 
     def prepare_config_and_inputs(self):
@@ -211,19 +189,32 @@ class Qwen2VLModelTest(ModelTesterMixin, GenerationTesterMixin, unittest.TestCas
     def test_config(self):
         self.config_tester.run_common_tests()
 
-    def test_initialization(self):
-        config, inputs_dict = self.model_tester.prepare_config_and_inputs_for_common()
+    def test_text_config(self):
+        config, _ = self.model_tester.prepare_config_and_inputs_for_common()
+        base_config_dict = config.to_dict()
+        base_config = Qwen2VLConfig(**base_config_dict)
 
-        configs_no_init = _config_zero_init(config)
-        for model_class in self.all_model_classes:
-            model = model_class(config=configs_no_init)
-            for name, param in model.named_parameters():
-                if param.requires_grad:
-                    self.assertIn(
-                        ((param.data.mean() * 1e9).round() / 1e9).item(),
-                        [0.0, 1.0],
-                        msg=f"Parameter {name} of model {model_class} seems not properly initialized",
-                    )
+        # Trying to get or set text related attributes happens via text config
+        vocab_size = base_config.vocab_size
+        text_vocab_size = base_config.text_config.vocab_size
+        self.assertEqual(vocab_size, text_vocab_size)
+
+        base_config.vocab_size = 55
+        self.assertEqual(base_config.vocab_size, 55)
+        self.assertEqual(base_config.text_config.vocab_size, 55)
+
+        # We can still initialize config from old-format json, i.e. flat structure
+        text_config_dict = base_config_dict.pop("text_config")
+        flat_config_dict = {**text_config_dict, **base_config_dict}
+        config_from_flat_dict = Qwen2VLConfig(**flat_config_dict)
+        config_from_flat_dict.vocab_size = 78
+        self.assertEqual(config_from_flat_dict.vocab_size, 78)
+        self.assertEqual(config_from_flat_dict.text_config.vocab_size, 78)
+
+        # Vision config attributes are NOT force-set via vision config
+        base_config.patch_size = 8
+        self.assertEqual(base_config.patch_size, 8)
+        self.assertNotEqual(base_config.vision_config.patch_size, 8)
 
     def test_mismatching_num_image_tokens(self):
         """
@@ -235,7 +226,7 @@ class Qwen2VLModelTest(ModelTesterMixin, GenerationTesterMixin, unittest.TestCas
         for model_class in self.all_model_classes:
             model = model_class(config).to(torch_device)
             curr_input_dict = copy.deepcopy(input_dict)
-            _ = model(**curr_input_dict)  # successfull forward with no modifications
+            _ = model(**curr_input_dict)  # successful forward with no modifications
 
             # remove one image but leave the image token in text
             patch_size = config.vision_config.patch_size
@@ -394,10 +385,6 @@ class Qwen2VLModelTest(ModelTesterMixin, GenerationTesterMixin, unittest.TestCas
     def test_multi_gpu_data_parallel_forward(self):
         pass
 
-    @unittest.skip(reason="We cannot configure to output a smaller model.")
-    def test_model_is_small(self):
-        pass
-
 
 @require_torch
 class Qwen2VLIntegrationTest(unittest.TestCase):
