@@ -15,6 +15,8 @@
 
 import unittest
 
+import pytest
+
 from transformers import AutoTokenizer, RobertaConfig, is_torch_available
 from transformers.testing_utils import TestCasePlus, require_torch, slow, torch_device
 
@@ -575,6 +577,7 @@ class RobertaModelIntegrationTest(TestCasePlus):
 
         torch.testing.assert_close(output, expected_tensor, rtol=1e-4, atol=1e-4)
 
+    @pytest.mark.torch_export_test
     @slow
     def test_export(self):
         if not is_torch_greater_or_equal_than_2_4:
