@@ -16,6 +16,7 @@
 import inspect
 import math
 import unittest
+from functools import cached_property
 
 from datasets import load_dataset
 
@@ -27,7 +28,7 @@ from transformers.testing_utils import (
     slow,
     torch_device,
 )
-from transformers.utils import cached_property, is_torch_available, is_vision_available
+from transformers.utils import is_torch_available, is_vision_available
 
 from ...test_configuration_common import ConfigTester
 from ...test_modeling_common import ModelTesterMixin, floats_tensor
