@@ -24,7 +24,6 @@ from transformers import T5GemmaConfig, T5GemmaModuleConfig, is_torch_available
 from transformers.testing_utils import (
     require_torch,
     require_torch_accelerator,
-    require_torch_gpu,
     torch_device,
 )
 
@@ -45,7 +44,6 @@ if is_torch_available():
         T5GemmaForTokenClassification,
         T5GemmaModel,
     )
-    from transformers.cache_utils import Cache
 
 
 class T5GemmaModelTester:
@@ -54,9 +52,9 @@ class T5GemmaModelTester:
 
     if is_torch_available():
         model_class = T5GemmaModel
-        for_causal_lm_class = T5GemmaForConditionalGeneration
-        for_sequence_class = T5GemmaForSequenceClassification
-        for_token_class = T5GemmaForTokenClassification
+        causal_lm_class = T5GemmaForConditionalGeneration
+        sequence_classification_class = T5GemmaForSequenceClassification
+        token_classification_class = T5GemmaForTokenClassification
 
     def __init__(
         self,
@@ -202,6 +200,15 @@ class T5GemmaModelTester:
         input_ids = torch.where(input_ids == self.bos_token_id, 42, input_ids)
         decoder_input_ids = torch.where(decoder_input_ids == self.bos_token_id, 42, decoder_input_ids)
 
+        # Avoid leading PAD tokens from inputs.
+        # `T5GemmaForTokenClassification` and `T5GemmaForSequenceClassification` specify `use_cache=False` when
+        # calling `self.model`. For `self.use_attention_mask=False` case below, the model goes through
+        # `make_default_2d_attention_mask`. When there are some pad tokens at the beginning of a sequence, it can't
+        # attend to any place, and the computed mask `[-3.4028e+38, -3.4028e+38, -3.4028e+38, -3.4028e+38, -3.4028e+38, -3.4028e+38, -3.4028e+38]`
+        # causes larger differences in some equivalence tests.
+        # Let's avoid such leading PAD tokens.
+        decoder_input_ids[:, 0] = self.pad_token_id + 1
+
         attention_mask = None
         decoder_attention_mask = None
         if self.use_attention_mask:
@@ -302,7 +309,7 @@ class T5GemmaModelTester:
         decoder_attention_mask,
         lm_labels,
     ):
-        model = self.for_causal_lm_class(config=config).to(torch_device).eval()
+        model = self.causal_lm_class(config=config).to(torch_device).eval()
         outputs = model(
             input_ids=input_ids,
             decoder_input_ids=decoder_input_ids,
@@ -324,7 +331,7 @@ class T5GemmaModelTester:
         lm_labels,
     ):
         labels = torch.tensor([1] * self.batch_size, dtype=torch.long, device=torch_device)
-        model = self.for_sequence_class(config=config).to(torch_device).eval()
+        model = self.sequence_classification_class(config=config).to(torch_device).eval()
         outputs = model(
             input_ids=input_ids,
             decoder_input_ids=input_ids,
@@ -344,7 +351,7 @@ class T5GemmaModelTester:
         is_encoder_decoder,
     ):
         labels = torch.tensor([1] * self.batch_size, dtype=torch.long, device=torch_device)
-        model = self.for_sequence_class(config=config, is_encoder_decoder=is_encoder_decoder)
+        model = self.sequence_classification_class(config=config, is_encoder_decoder=is_encoder_decoder)
         model = model.to(torch_device).eval()
         outputs = model(
             input_ids=input_ids,
@@ -366,7 +373,7 @@ class T5GemmaModelTester:
         is_encoder_decoder,
     ):
         labels = torch.tensor([1] * self.seq_length * self.batch_size, dtype=torch.long, device=torch_device)
-        model = self.for_token_class(config=config, is_encoder_decoder=is_encoder_decoder)
+        model = self.token_classification_class(config=config, is_encoder_decoder=is_encoder_decoder)
         model = model.to(torch_device).eval()
         outputs = model(
             input_ids=input_ids,
@@ -537,7 +544,7 @@ class T5GemmaModelTester:
         decoder_attention_mask,
         lm_labels,
     ):
-        model = self.for_causal_lm_class(config=config).to(torch_device).eval()
+        model = self.causal_lm_class(config=config).to(torch_device).eval()
         torch.manual_seed(0)
         output_without_past_cache = model.generate(
             input_ids[:1], num_beams=2, max_length=5, do_sample=True, use_cache=False
@@ -589,7 +596,6 @@ class T5GemmaModelTest(ModelTesterMixin, GenerationTesterMixin, PipelineTesterMi
     test_pruning = False
     _is_stateful = True
     is_encoder_decoder = True
-    model_split_percents = [0.5, 0.6]
 
     # used in `test_torch_compile_for_training`
     _torch_compile_train_cls = T5GemmaForConditionalGeneration if is_torch_available() else None
@@ -760,7 +766,7 @@ class T5GemmaModelTest(ModelTesterMixin, GenerationTesterMixin, PipelineTesterMi
 
         for is_encoder_decoder in [True, False]:
             model = (
-                self.model_tester.for_sequence_class(config, is_encoder_decoder=is_encoder_decoder)
+                self.model_tester.sequence_classification_class(config, is_encoder_decoder=is_encoder_decoder)
                 .to(torch_device)
                 .eval()
             )
@@ -778,7 +784,7 @@ class T5GemmaModelTest(ModelTesterMixin, GenerationTesterMixin, PipelineTesterMi
 
         for is_encoder_decoder in [True, False]:
             model = (
-                self.model_tester.for_sequence_class(config, is_encoder_decoder=is_encoder_decoder)
+                self.model_tester.sequence_classification_class(config, is_encoder_decoder=is_encoder_decoder)
                 .to(torch_device)
                 .eval()
             )
@@ -798,7 +804,7 @@ class T5GemmaModelTest(ModelTesterMixin, GenerationTesterMixin, PipelineTesterMi
 
         for is_encoder_decoder in [True, False]:
             model = (
-                self.model_tester.for_sequence_class(config, is_encoder_decoder=is_encoder_decoder)
+                self.model_tester.sequence_classification_class(config, is_encoder_decoder=is_encoder_decoder)
                 .to(torch_device)
                 .eval()
             )
@@ -815,7 +821,7 @@ class T5GemmaModelTest(ModelTesterMixin, GenerationTesterMixin, PipelineTesterMi
 
         for is_encoder_decoder in [True, False]:
             model = (
-                self.model_tester.for_token_class(config, is_encoder_decoder=is_encoder_decoder)
+                self.model_tester.token_classification_class(config, is_encoder_decoder=is_encoder_decoder)
                 .to(torch_device)
                 .eval()
             )
@@ -881,7 +887,10 @@ class T5GemmaModelTest(ModelTesterMixin, GenerationTesterMixin, PipelineTesterMi
 
         for model_class in self.all_model_classes:
             # Skip token and sequence classification.
-            if model_class in [self.model_tester.for_token_class, self.model_tester.for_sequence_class]:
+            if model_class in [
+                self.model_tester.token_classification_class,
+                self.model_tester.sequence_classification_class,
+            ]:
                 continue
 
             inputs_dict["output_attentions"] = True
@@ -983,126 +992,6 @@ class T5GemmaModelTest(ModelTesterMixin, GenerationTesterMixin, PipelineTesterMi
                     [self.model_tester.num_attention_heads, encoder_seq_length, encoder_key_length],
                 )
 
-    # Based on tests.generation.test_utils.GenerationTesterMixin.test_past_key_values_format
-    # Adjust encoder attention number for cross-attention caching and update attention head dimension
-    @pytest.mark.generate
-    def test_past_key_values_format(self, custom_all_cache_shapes=None):
-        """
-        Test that the KV cache is formatted correctly. Exceptions need to explicitly overwrite this test, or pass the
-        expected cache shapes.
-        Having a standard KV cache format is important for a consistent API (and for advanced generation methods).
-        """
-        for model_class in self.all_generative_model_classes:
-            config, inputs = self.model_tester.prepare_config_and_inputs_for_common()
-
-            # 1. If it doesn't support cache, skip the test
-            if not hasattr(config.get_text_config(), "use_cache"):
-                self.skipTest(reason=f"{model_class.__name__} doesn't support caching")
-
-            model = model_class(config).to(torch_device)
-            model = model.eval()
-            if "use_cache" not in inputs:
-                inputs["use_cache"] = True
-            outputs = model(**inputs)
-
-            if "past_key_values" not in outputs:
-                self.skipTest(reason="This model doesn't return `past_key_values`")
-
-            # 2. retrieve the KV cache and compute its default expected shapes (if no custom shapes are provided)
-            past_kv = outputs["past_key_values"]
-            is_legacy_cache = not isinstance(past_kv, Cache)
-
-            text_config = config.get_text_config().decoder
-            num_decoder_layers = text_config.num_hidden_layers
-
-            if custom_all_cache_shapes is None:
-                num_query_attention_heads = getattr(
-                    text_config, "decoder_attention_heads", text_config.num_attention_heads
-                )
-                per_head_embed_dim = text_config.head_dim
-                num_key_value_heads = (
-                    text_config.num_key_value_heads
-                    if getattr(text_config, "num_key_value_heads", None) is not None
-                    else num_query_attention_heads
-                )
-                if config.is_encoder_decoder:
-                    encoder_num_attention_heads = num_key_value_heads
-                    encoder_per_head_embed_dim = per_head_embed_dim
-                    batch_size, seq_length = inputs["decoder_input_ids"].shape[:2]
-                    # The sequence length for the encoder K V depends on the model. Since it is not manipulated in
-                    # autoregressive generation, we're keeping the test general and not checking the 3rd dim
-                    default_cross_attention_shape = (
-                        batch_size,
-                        encoder_num_attention_heads,
-                        encoder_per_head_embed_dim,
-                    )
-                    default_self_attention_shape = (batch_size, num_key_value_heads, seq_length, per_head_embed_dim)
-                    all_cache_shapes = [
-                        [
-                            default_self_attention_shape,
-                            default_self_attention_shape,
-                            default_cross_attention_shape,
-                            default_cross_attention_shape,
-                        ]
-                        for _ in range(num_decoder_layers)
-                    ]
-                else:
-                    batch_size, seq_length = inputs["input_ids"].shape[:2]
-                    default_self_attention_shape = (batch_size, num_key_value_heads, seq_length, per_head_embed_dim)
-                    all_cache_shapes = [
-                        [default_self_attention_shape, default_self_attention_shape] for _ in range(num_decoder_layers)
-                    ]
-
-            else:
-                all_cache_shapes = custom_all_cache_shapes
-
-            # 3. Check cache shapes
-            # 3.1. Encoder-Decoder checks
-            if config.is_encoder_decoder:
-                num_cache_decoder_layers = len(past_kv) if is_legacy_cache else len(past_kv.self_attention_cache)
-                self.assertEqual(num_cache_decoder_layers, num_decoder_layers)
-
-                for i in range(num_decoder_layers):
-                    if is_legacy_cache:
-                        self.assertEqual(len(past_kv[0]), 5)  # legacy check: confirm number of elements in tuple
-
-                    # Self attention
-                    self_attention_layer_keys = (
-                        past_kv[i][0] if is_legacy_cache else past_kv.self_attention_cache.layers[i].keys
-                    )
-                    self_attention_layer_values = (
-                        past_kv[i][1] if is_legacy_cache else past_kv.self_attention_cache.layers[i].values
-                    )
-                    self.assertEqual(self_attention_layer_keys.shape, all_cache_shapes[i][0])
-                    self.assertEqual(self_attention_layer_values.shape, all_cache_shapes[i][1])
-
-                    # Cross attention (ignore 3rd dim, see default shape preparation)
-                    cross_attention_layer_keys = (
-                        past_kv[i][2] if is_legacy_cache else past_kv.cross_attention_cache.layers[i].keys
-                    )
-                    cross_attention_layer_values = (
-                        past_kv[i][3] if is_legacy_cache else past_kv.cross_attention_cache.layers[i].values
-                    )
-                    cross_attention_layer_keys = cross_attention_layer_keys[:, :, 0, :]
-                    cross_attention_layer_values = cross_attention_layer_values[:, :, 0, :]
-                    self.assertEqual(cross_attention_layer_keys.shape, all_cache_shapes[i][2])
-                    self.assertEqual(cross_attention_layer_values.shape, all_cache_shapes[i][3])
-
-            # 3.2. Decoder-only checks
-            else:
-                num_cache_decoder_layers = len(past_kv) if is_legacy_cache else len(past_kv)
-                self.assertEqual(num_cache_decoder_layers, num_decoder_layers)
-
-                for i in range(num_decoder_layers):
-                    if is_legacy_cache:
-                        self.assertEqual(len(past_kv[0]), 2)  # legacy check: confirm number of elements in tuple
-
-                    # Self attention
-                    self_attention_layer_keys = past_kv[i][0] if is_legacy_cache else past_kv.layers[i].keys
-                    self_attention_layer_values = past_kv[i][1] if is_legacy_cache else past_kv.layers[i].values
-                    self.assertEqual(self_attention_layer_keys.shape, all_cache_shapes[i][0])
-                    self.assertEqual(self_attention_layer_values.shape, all_cache_shapes[i][1])
-
     @unittest.skip("Mismatch issue doesn't exist in T5Gemma.")
     def test_load_with_mismatched_shapes(self):
         pass
@@ -1113,7 +1002,7 @@ class T5GemmaModelTest(ModelTesterMixin, GenerationTesterMixin, PipelineTesterMi
     def test_generate_continue_from_past_key_values(self):
         # Tests that we can continue generating from past key values, returned from a previous `generate` call
         for model_class in self.all_generative_model_classes:
-            if model_class == self.model_tester.for_token_class:
+            if model_class == self.model_tester.token_classification_class:
                 continue
             if any(model_name in model_class.__name__.lower() for model_name in ["imagegpt", "mllama"]):
                 self.skipTest(reason="Won't fix: old model with unique inputs/caches/other")
@@ -1245,7 +1134,10 @@ class T5GemmaModelTest(ModelTesterMixin, GenerationTesterMixin, PipelineTesterMi
     @unittest.skip("This was not properly written, submodules need the attribute to be overwritten")
     def test_hidden_states_output(self):
         def check_hidden_states_output(inputs_dict, config, model_class):
-            if model_class in [self.model_tester.for_token_class, self.model_tester.for_sequence_class]:
+            if model_class in [
+                self.model_tester.token_classification_class,
+                self.model_tester.sequence_classification_class,
+            ]:
                 model = model_class(config, is_encoder_decoder=False)
             else:
                 model = model_class(config)
@@ -1338,7 +1230,7 @@ class T5GemmaModelTest(ModelTesterMixin, GenerationTesterMixin, PipelineTesterMi
 
     # Based on tests.test_modeling_common.ModelTesterMixin.test_flex_attention_with_grads
     # Update hidden size for encoder and decoder
-    @require_torch_gpu
+    @require_torch_accelerator
     def test_flex_attention_with_grads(self):
         for model_class in self.all_model_classes:
             # TODO: raushan, fix for composite models after making VLMs support new attn API
@@ -1572,7 +1464,6 @@ class T5GemmaEncoderOnlyModelTest(ModelTesterMixin, unittest.TestCase):
     test_headmasking = False
     _is_stateful = True
     is_encoder_decoder = False
-    model_split_percents = [0.4, 0.5]
 
     # won't fix
     test_torchscript = False
@@ -1624,7 +1515,7 @@ class T5GemmaEncoderOnlyModelTest(ModelTesterMixin, unittest.TestCase):
 
     # Based on tests.test_modeling_common.ModelTesterMixin.test_flex_attention_with_grads
     # Update hidden size for encoder
-    @require_torch_gpu
+    @require_torch_accelerator
     def test_flex_attention_with_grads(self):
         for model_class in self.all_model_classes:
             # TODO: raushan, fix for composite models after making VLMs support new attn API
