@@ -53,14 +53,15 @@ class TimmWrapperModelTester:
     def __init__(
         self,
         parent,
-        model_name="timm/resnet18.a1_in1k",
         batch_size=3,
         image_size=32,
         num_channels=3,
         is_training=True,
     ):
         self.parent = parent
-        self.model_name = model_name
+        self.architecture = "resnet26"
+        # We need this to make the model smaller
+        self.model_args = {"channels": (16, 16, 16, 16)}
         self.batch_size = batch_size
         self.image_size = image_size
         self.num_channels = num_channels
@@ -73,7 +74,7 @@ class TimmWrapperModelTester:
         return config, pixel_values
 
     def get_config(self):
-        return TimmWrapperConfig.from_pretrained(self.model_name)
+        return TimmWrapperConfig(architecture=self.architecture, model_args=self.model_args)
 
     def prepare_config_and_inputs_for_common(self):
         config_and_inputs = self.prepare_config_and_inputs()
@@ -158,18 +159,6 @@ class TimmWrapperModelTest(ModelTesterMixin, PipelineTesterMixin, unittest.TestC
     def test_can_init_all_missing_weights(self):
         pass
 
-    @unittest.skip(reason="TimmWrapper initialization is managed on the timm side")
-    def test_initialization(self):
-        pass
-
-    @unittest.skip(reason="TimmWrapper initialization is managed on the timm side")
-    def test_mismatched_shapes_have_properly_initialized_weights(self):
-        pass
-
-    @unittest.skip(reason="Need to use a timm model and there is no tiny model available.")
-    def test_model_is_small(self):
-        pass
-
     def test_gradient_checkpointing(self):
         config, _ = self.model_tester.prepare_config_and_inputs_for_common()
         model = TimmWrapperModel._from_config(config)
