@@ -16,6 +16,7 @@
 import inspect
 import json
 import random
+import sys
 import tempfile
 from pathlib import Path
 from typing import Optional, Union
@@ -33,7 +34,11 @@ from transformers.testing_utils import (
     require_torch,
     require_vision,
 )
-from transformers.utils import is_av_available, is_torch_available, is_vision_available
+from transformers.utils import is_torch_available, is_vision_available
+
+
+sys.path.append(".")
+from utils.fetch_hub_objects_for_ci import url_to_local_path
 
 
 global_rng = random.Random()
@@ -59,14 +64,9 @@ MODALITY_INPUT_DATA = {
     ],
 }
 
-if is_av_available():
-    from transformers.video_utils import load_video
 
-    # load a video file in memory for testing
-    video, _ = load_video(
-        "https://huggingface.co/datasets/raushan-testing-hf/videos-test/resolve/main/Big_Buck_Bunny_720_10s_10MB.mp4"
-    )
-    MODALITY_INPUT_DATA["videos"].append(video)
+for modality, urls in MODALITY_INPUT_DATA.items():
+    MODALITY_INPUT_DATA[modality] = [url_to_local_path(url) for url in urls]
 
 
 def prepare_image_inputs():
@@ -170,6 +170,7 @@ class ProcessorTesterMixin:
     def prepare_video_inputs(self, batch_size: Optional[int] = None):
         """This function prepares a list of numpy videos."""
         video_input = [np.random.randint(255, size=(3, 30, 400), dtype=np.uint8)] * 8
+        video_input = np.array(video_input)
         if batch_size is None:
             return video_input
         return [video_input] * batch_size
@@ -264,6 +265,92 @@ class ProcessorTesterMixin:
 
         self.assertSetEqual(set(inputs.keys()), set(processor.model_input_names))
 
+    def test_processor_text_has_no_visual(self):
+        """
+        Tests that multimodal models can process batch of inputs where samples can
+        be with images/videos or without. See https://github.com/huggingface/transformers/issues/40263
+        """
+        processor = self.get_processor()
+        call_signature = inspect.signature(processor.__call__)
+        input_args = [param.name for param in call_signature.parameters.values() if param.annotation != param.empty]
+
+        if not ("text" in input_args and ("images" in input_args and "videos" in input_args)):
+            self.skipTest(f"{self.processor_class} doesn't support several vision modalities with text.")
+
+        # Prepare inputs and filter by input signature. Make sure to use a high batch size, we'll set some
+        # samples to text-only later
+        text = self.prepare_text_inputs(batch_size=3, modalities=["image", "video"])
+        image_inputs = self.prepare_image_inputs(batch_size=3)
+        video_inputs = self.prepare_video_inputs(batch_size=3)
+        inputs_dict = {"text": text, "images": image_inputs, "videos": video_inputs}
+        inputs_dict = {k: v for k, v in inputs_dict.items() if k in input_args}
+
+        processing_kwargs = {"return_tensors": "pt", "padding": True}
+        if "videos" in inputs_dict:
+            processing_kwargs["do_sample_frames"] = False
+
+        # First call processor with all inputs and use nested input type, which is the format supported by all multimodal processors
+        image_inputs_nested = [[image] if not isinstance(image, list) else image for image in image_inputs]
+        video_inputs_nested = [[video] for video in video_inputs]
+        inputs_dict_nested = {"text": text, "images": image_inputs_nested, "videos": video_inputs_nested}
+        inputs_dict_nested = {k: v for k, v in inputs_dict_nested.items() if k in input_args}
+        inputs = processor(**inputs_dict_nested, **processing_kwargs)
+        self.assertTrue(self.text_input_name in inputs)
+
+        # Now call with one of the samples with no associated vision input. Let's set the first input to be a plain text
+        # with no placeholder tokens and no images/videos. The final format would be `images = [[], [image2], [image3]]`
+        plain_text = "lower newer"
+        image_inputs_nested[0] = []
+        video_inputs_nested[0] = []
+        text[0] = plain_text
+        inputs_dict_no_vision = {"text": text, "images": image_inputs_nested, "videos": video_inputs_nested}
+        inputs_dict_no_vision = {k: v for k, v in inputs_dict_no_vision.items() if k in input_args}
+        inputs_nested = processor(**inputs_dict_no_vision, **processing_kwargs)
+
+        # Check that text samples are same and are expanded with placeholder tokens correctly. First sample
+        # has no vision input associated, so we skip it and check it has no vision
+        self.assertListEqual(
+            inputs[self.text_input_name][1:].tolist(), inputs_nested[self.text_input_name][1:].tolist()
+        )
+
+        # Now test if we can apply chat templates with no vision inputs in one of the samples
+        # NOTE: we don't skip the test as we want the above to be checked even if process has to chat template
+        if processor.chat_template is not None:
+            messages = [
+                [
+                    {
+                        "role": "user",
+                        "content": [
+                            {"type": "text", "text": "What is the capital of France?"},
+                        ],
+                    },
+                ],
+                [
+                    {
+                        "role": "user",
+                        "content": [
+                            {"type": "text", "text": "What is the capital of France?"},
+                            {
+                                "type": "image",
+                                "url": url_to_local_path(
+                                    "https://huggingface.co/datasets/huggingface/documentation-images/resolve/main/coco_sample.png"
+                                ),
+                            },
+                        ],
+                    },
+                ],
+            ]
+
+            inputs_chat_template = processor.apply_chat_template(
+                messages,
+                add_generation_prompt=False,
+                tokenize=True,
+                return_dict=True,
+                return_tensors="pt",
+                padding=True,
+            )
+            self.assertTrue(self.text_input_name in inputs_chat_template)
+
     # These kwargs-related tests ensure that processors are correctly instantiated.
     # they need to be applied only if an image_processor exists.
 
@@ -788,7 +875,8 @@ class ProcessorTesterMixin:
             self.skipTest(f"image_processor attribute not present in {self.processor_class}")
 
         processor_components = self.prepare_components()
-        processor = self.processor_class(**processor_components)
+        processor_kwargs = self.prepare_processor_dict()
+        processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
         input_str = self.prepare_text_inputs(modalities="image")
@@ -918,10 +1006,8 @@ class ProcessorTesterMixin:
 
         batch_messages = [
             [
-                {
-                    "role": "user",
-                    "content": [{"type": "text", "text": "Describe this."}],
-                },
+                {"role": "system", "content": [{"type": "text", "text": "You are a helpful assistant."}]},
+                {"role": "user", "content": [{"type": "text", "text": "Describe this."}]},
             ]
         ] * batch_size
 
@@ -968,7 +1054,7 @@ class ProcessorTesterMixin:
 
         # Test that with modality URLs and `return_dict=True`, we get modality inputs in the dict
         for idx, url in enumerate(input_data[:batch_size]):
-            batch_messages[idx][0]["content"] = [batch_messages[idx][0]["content"][0], {"type": modality, "url": url}]
+            batch_messages[idx][1]["content"] = [batch_messages[idx][1]["content"][0], {"type": modality, "url": url}]
 
         out_dict = processor.apply_chat_template(
             batch_messages,
@@ -1006,6 +1092,15 @@ class ProcessorTesterMixin:
             "audio", batch_size, return_tensors, "audio_input_name", "feature_extractor", MODALITY_INPUT_DATA["audio"]
         )
 
+    @require_av
+    @parameterized.expand([(1, "pt")])
+    def test_apply_chat_template_decoded_video(self, batch_size: int, return_tensors: str):
+        dummy_preloaded_video = np.array(self.prepare_video_inputs())
+        input_data = [dummy_preloaded_video]
+        self._test_apply_chat_template(
+            "video", batch_size, return_tensors, "videos_input_name", "video_processor", input_data
+        )
+
     @require_av
     @parameterized.expand([(1, "pt"), (2, "pt")])  # video processor supports only torchvision
     def test_apply_chat_template_video(self, batch_size: int, return_tensors: str):
@@ -1040,7 +1135,9 @@ class ProcessorTesterMixin:
                     "content": [
                         {
                             "type": "video",
-                            "url": "https://test-videos.co.uk/vids/bigbuckbunny/mp4/h264/720/Big_Buck_Bunny_720_10s_10MB.mp4",
+                            "url": url_to_local_path(
+                                "https://huggingface.co/datasets/raushan-testing-hf/videos-test/resolve/main/tiny_video.mp4"
+                            ),
                         },
                         {"type": "text", "text": "What is shown in this video?"},
                     ],
@@ -1062,7 +1159,7 @@ class ProcessorTesterMixin:
         self.assertEqual(len(out_dict_with_video[self.videos_input_name][0]), num_frames)
 
         # Load with `fps` arg
-        fps = 1
+        fps = 10
         out_dict_with_video = processor.apply_chat_template(
             messages,
             add_generation_prompt=True,
@@ -1073,10 +1170,11 @@ class ProcessorTesterMixin:
         )
         self.assertTrue(self.videos_input_name in out_dict_with_video)
         self.assertEqual(len(out_dict_with_video[self.videos_input_name]), 1)
-        self.assertEqual(len(out_dict_with_video[self.videos_input_name][0]), fps * 10)
+        # 3 frames are inferred from input video's length and FPS, so can be hardcoded
+        self.assertEqual(len(out_dict_with_video[self.videos_input_name][0]), 3)
 
-        # Whan `do_sample_frames=False` no sampling is done and whole video is loaded, even if number of frames is passed
-        fps = 1
+        # When `do_sample_frames=False` no sampling is done and whole video is loaded, even if number of frames is passed
+        fps = 10
         out_dict_with_video = processor.apply_chat_template(
             messages,
             add_generation_prompt=True,
@@ -1088,7 +1186,7 @@ class ProcessorTesterMixin:
         )
         self.assertTrue(self.videos_input_name in out_dict_with_video)
         self.assertEqual(len(out_dict_with_video[self.videos_input_name]), 1)
-        self.assertEqual(len(out_dict_with_video[self.videos_input_name][0]), 300)
+        self.assertEqual(len(out_dict_with_video[self.videos_input_name][0]), 11)
 
         # Load with `fps` and `num_frames` args, should raise an error
         with self.assertRaises(ValueError):
@@ -1110,16 +1208,18 @@ class ProcessorTesterMixin:
         )
         self.assertTrue(self.videos_input_name in out_dict_with_video)
         self.assertEqual(len(out_dict_with_video[self.videos_input_name]), 1)
-        self.assertEqual(len(out_dict_with_video[self.videos_input_name][0]), 300)
+        self.assertEqual(len(out_dict_with_video[self.videos_input_name][0]), 11)
 
         # Load video as a list of frames (i.e. images).
         # NOTE: each frame should have same size because we assume they come from one video
         messages[0][0]["content"][0] = {
             "type": "video",
             "url": [
-                "https://www.ilankelman.org/stopsigns/australia.jpg",
-                "https://www.ilankelman.org/stopsigns/australia.jpg",
-            ],
+                url_to_local_path(
+                    "https://huggingface.co/datasets/huggingface/documentation-images/resolve/main/transformers/tasks/australia.jpg"
+                )
+            ]
+            * 2,
         }
         out_dict_with_video = processor.apply_chat_template(
             messages,
