@@ -81,6 +81,7 @@ ALWAYS_OVERRIDE = ["labels"]
 OBJECTS_TO_IGNORE = {
     "ApertusConfig",
     "Mxfp4Config",
+    "Qwen3OmniMoeConfig",
     "Exaone4Config",
     "SmolLM3Config",
     "Gemma3nVisionConfig",
@@ -128,6 +129,8 @@ OBJECTS_TO_IGNORE = {
     "BlipVisionConfig",
     "BloomConfig",
     "BloomTokenizerFast",
+    "BLTConfig",
+    "BLTPatcherConfig",
     "BridgeTowerTextConfig",
     "BridgeTowerVisionConfig",
     "BrosModel",
@@ -312,6 +315,7 @@ OBJECTS_TO_IGNORE = {
     "OpenAIGPTTokenizerFast",
     "OpenLlamaConfig",
     "PLBartConfig",
+    "ParakeetCTCConfig",
     "PegasusConfig",
     "PegasusTokenizer",
     "PegasusTokenizerFast",
@@ -460,6 +464,8 @@ OBJECTS_TO_IGNORE = {
     "ZeroShotImageClassificationPipeline",
     "ZeroShotObjectDetectionPipeline",
     "Llama4TextConfig",
+    "BltConfig",
+    "BltPatcherConfig",
 }
 # In addition to the objects above, we also ignore objects with certain prefixes. If you add an item to the list
 # below, make sure to add a comment explaining why.
